@@ -97,6 +97,18 @@ UPCM <- function(Y, X = NULL, GPCM = TRUE, Q = 10, cores = 2, lambda = 1e-2, se
     stop("X has to be a matrix!")
   }}
   
+  if(sum(is.na(Y)>0)){
+    Y <- Y[complete.cases(Y),]
+    warning("Observations with missing responses have been deleted!")
+  }
+  
+  if(sum(is.na(X)>0)){
+      X <- X[complete.cases(X),]
+    warning("Observations with missing explanatory variables have been deleted!")
+  }
+  
+
+  
   ## initalize response vector and other parameters
   y.vec <- as.factor(c(t(Y)))
   k <- length(levels(y.vec))
