@@ -14,7 +14,7 @@
 #include <omp.h>
 #endif
 
-using namespace std;
+//using namespace std;
 using namespace Rcpp;
 using namespace arma;
 
